Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(3454)

Unified Diff: chrome/browser/ui/webui/welcome_win10_handler.h

Issue 2479773002: Add chrome namespace to chrome/common/shell_handler_win.mojom (Closed)
Patch Set: Add chrome namespace to chrome/common/shell_handler_win.mojom Created 4 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/browser/shell_integration_win.cc ('k') | chrome/browser/ui/webui/welcome_win10_handler.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/ui/webui/welcome_win10_handler.h
diff --git a/chrome/browser/ui/webui/welcome_win10_handler.h b/chrome/browser/ui/webui/welcome_win10_handler.h
index aafbf863d00fe749fcf6c292dc780d884b724537..6220e0cc03291a32b540823c10cfb75787141a5c 100644
--- a/chrome/browser/ui/webui/welcome_win10_handler.h
+++ b/chrome/browser/ui/webui/welcome_win10_handler.h
@@ -36,7 +36,7 @@ class WelcomeWin10Handler : public content::WebUIMessageHandler {
void StartIsPinnedToTaskbarCheck();
// Callback for mojom::ShellHandler's call to IsPinnedToTaskbar().
void OnIsPinnedToTaskbarResult(bool succeeded, bool is_pinned_to_taskbar);
// Sets the internal result and optionally call
@@ -48,7 +48,8 @@ class WelcomeWin10Handler : public content::WebUIMessageHandler {
// promise.
void SendPinnedToTaskbarStateResult();
- std::unique_ptr<content::UtilityProcessMojoClient<mojom::ShellHandler>>
+ std::unique_ptr<
+ content::UtilityProcessMojoClient<chrome::mojom::ShellHandler>>
client_;
base::OneShotTimer timer_;
« no previous file with comments | « chrome/browser/shell_integration_win.cc ('k') | chrome/browser/ui/webui/welcome_win10_handler.cc » ('j') | no next file with comments »
@@ -36,7 +36,7 @@ class WelcomeWin10Handler : public content::WebUIMessageHandler {
void StartIsPinnedToTaskbarCheck();
- // Callback for mojom::ShellHandler's call to IsPinnedToTaskbar().
+ // Callback for chrome::mojom::ShellHandler's call to IsPinnedToTaskbar().
void OnIsPinnedToTaskbarResult(bool succeeded, bool is_pinned_to_taskbar);
// Sets the internal result and optionally call

Powered by Google App Engine
This is Rietveld 408576698